# Copyright 2025 Snowflake Inc.
# SPDX-License-Identifier: Apache-2.0
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# http://www.apache.org/licenses/LICENSE-2.0
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Connection models for different database dialects."""

# Import SQL Server connection models
from snowflake.snowflake_data_validation.sqlserver.model.sqlserver_credentials_connection import (
    SqlServerCredentialsConnection,
)

# Import Teradata connection models
from snowflake.snowflake_data_validation.teradata.model.teradata_credentials_connection import (
    TeradataCredentialsConnection,
)

# Import Snowflake connection models
from snowflake.snowflake_data_validation.snowflake.model.snowflake_default_connection import (
    SnowflakeDefaultConnection,
)
from snowflake.snowflake_data_validation.snowflake.model.snowflake_named_connection import (
    SnowflakeNamedConnection,
)

__all__ = [
    "SqlServerCredentialsConnection",
    "TeradataCredentialsConnection",
    "SnowflakeDefaultConnection",
    "SnowflakeNamedConnection",
]
